
``sphinxgen`` python package
=================================



.. toctree::
    :maxdepth: 1

    
    code_sphinxgen.version
    



.. automodule:: sphinxgen
    :members:
    :undoc-members:
    :show-inheritance:

